# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr
from public_api_server_connector.models.api_key_get import ApiKeyGet

class ApiKeyCreateResponse(BaseModel):
    """
    ApiKeyCreateResponse
    """
    id: StrictInt = Field(default=..., description="The unique identifier of the API key.")
    api_key: StrictStr = Field(default=..., description="The API key that was created.")
    api_key_entity: ApiKeyGet = Field(default=..., description="The details of the created API key.")
    __properties = ["id", "api_key", "api_key_entity"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiKeyCreateResponse:
        """Create an instance of ApiKeyCreateResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of api_key_entity
        if self.api_key_entity:
            _dict['api_key_entity'] = self.api_key_entity.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiKeyCreateResponse:
        """Create an instance of ApiKeyCreateResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiKeyCreateResponse.parse_obj(obj)

        _obj = ApiKeyCreateResponse.parse_obj({
            "id": obj.get("id"),
            "api_key": obj.get("api_key"),
            "api_key_entity": ApiKeyGet.from_dict(obj.get("api_key_entity")) if obj.get("api_key_entity") is not None else None
        })
        return _obj


