# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt
from public_api_server_connector.models.content import Content
from public_api_server_connector.models.content_block_type_str_enum import ContentBlockTypeStrEnum

class CourseContentBlock(BaseModel):
    """
    CourseContentBlock
    """
    block_type: ContentBlockTypeStrEnum = Field(...)
    order: StrictInt = Field(...)
    is_expanded: StrictBool = Field(...)
    content: Optional[Content] = None
    id: StrictInt = Field(...)
    course_id: StrictInt = Field(...)
    created_at: StrictInt = Field(default=..., description="Unix timestamp in milliseconds when the content block was created")
    __properties = ["block_type", "order", "is_expanded", "content", "id", "course_id", "created_at"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CourseContentBlock:
        """Create an instance of CourseContentBlock from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of content
        if self.content:
            _dict['content'] = self.content.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CourseContentBlock:
        """Create an instance of CourseContentBlock from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CourseContentBlock.parse_obj(obj)

        _obj = CourseContentBlock.parse_obj({
            "block_type": obj.get("block_type"),
            "order": obj.get("order"),
            "is_expanded": obj.get("is_expanded"),
            "content": Content.from_dict(obj.get("content")) if obj.get("content") is not None else None,
            "id": obj.get("id"),
            "course_id": obj.get("course_id"),
            "created_at": obj.get("created_at")
        })
        return _obj


