# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from public_api_server_connector.models.course_submodule import CourseSubmodule
from public_api_server_connector.models.module_lesson import ModuleLesson

class CourseModule(BaseModel):
    """
    CourseModule
    """
    mandatory: Optional[StrictBool] = False
    is_published: Optional[StrictBool] = False
    is_active: Optional[StrictBool] = False
    title: StrictStr = Field(...)
    public_description: Optional[StrictStr] = None
    short_description: Optional[StrictStr] = None
    image_id: Optional[StrictStr] = None
    available_at: Optional[StrictInt] = Field(default=None, description="Timestamp in unix milliseconds when the module becomes available")
    id: StrictInt = Field(...)
    course_id: StrictInt = Field(...)
    order: StrictInt = Field(...)
    submodules: conlist(CourseSubmodule) = Field(...)
    lessons: conlist(ModuleLesson) = Field(...)
    __properties = ["mandatory", "is_published", "is_active", "title", "public_description", "short_description", "image_id", "available_at", "id", "course_id", "order", "submodules", "lessons"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CourseModule:
        """Create an instance of CourseModule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in submodules (list)
        _items = []
        if self.submodules:
            for _item in self.submodules:
                if _item:
                    _items.append(_item.to_dict())
            _dict['submodules'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in lessons (list)
        _items = []
        if self.lessons:
            for _item in self.lessons:
                if _item:
                    _items.append(_item.to_dict())
            _dict['lessons'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CourseModule:
        """Create an instance of CourseModule from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CourseModule.parse_obj(obj)

        _obj = CourseModule.parse_obj({
            "mandatory": obj.get("mandatory") if obj.get("mandatory") is not None else False,
            "is_published": obj.get("is_published") if obj.get("is_published") is not None else False,
            "is_active": obj.get("is_active") if obj.get("is_active") is not None else False,
            "title": obj.get("title"),
            "public_description": obj.get("public_description"),
            "short_description": obj.get("short_description"),
            "image_id": obj.get("image_id"),
            "available_at": obj.get("available_at"),
            "id": obj.get("id"),
            "course_id": obj.get("course_id"),
            "order": obj.get("order"),
            "submodules": [CourseSubmodule.from_dict(_item) for _item in obj.get("submodules")] if obj.get("submodules") is not None else None,
            "lessons": [ModuleLesson.from_dict(_item) for _item in obj.get("lessons")] if obj.get("lessons") is not None else None
        })
        return _obj


