# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from public_api_server_connector.models.category_method_options import CategoryMethodOptions

class Category(BaseModel):
    """
    Category
    """
    name: StrictStr = Field(...)
    create: Optional[CategoryMethodOptions] = None
    read: Optional[CategoryMethodOptions] = None
    update: Optional[CategoryMethodOptions] = None
    delete: Optional[CategoryMethodOptions] = None
    __properties = ["name", "create", "read", "update", "delete"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Category:
        """Create an instance of Category from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of create
        if self.create:
            _dict['create'] = self.create.to_dict()
        # override the default output from pydantic by calling `to_dict()` of read
        if self.read:
            _dict['read'] = self.read.to_dict()
        # override the default output from pydantic by calling `to_dict()` of update
        if self.update:
            _dict['update'] = self.update.to_dict()
        # override the default output from pydantic by calling `to_dict()` of delete
        if self.delete:
            _dict['delete'] = self.delete.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Category:
        """Create an instance of Category from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Category.parse_obj(obj)

        _obj = Category.parse_obj({
            "name": obj.get("name"),
            "create": CategoryMethodOptions.from_dict(obj.get("create")) if obj.get("create") is not None else None,
            "read": CategoryMethodOptions.from_dict(obj.get("read")) if obj.get("read") is not None else None,
            "update": CategoryMethodOptions.from_dict(obj.get("update")) if obj.get("update") is not None else None,
            "delete": CategoryMethodOptions.from_dict(obj.get("delete")) if obj.get("delete") is not None else None
        })
        return _obj


